@@ -21,7 +21,7 @@ def _set_default_status(kwargs: dict[str, Any], status: int):
 
 
 def _overload_function(target: APIRouter, name: str, func: Callable) -> None:
-    setattr(target, name, partial(func, self=target))
+    setattr(target, name, partial(func, target))
 
 
 def router_factory(create_post: bool, no_content_delete: bool):
